==> gtk-sharp-2.10.2-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.glade-sharp.dll policy.2.4.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-sharp/2.10.0.0__35e10195dab3c99f/gtk-sharp.dll gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.6.gtk-dotnet.dll policy.2.6.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gtk-sharp.dll policy.2.6.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.pango-sharp.dll policy.2.6.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gdk-sharp/2.10.0.0__35e10195dab3c99f/gdk-sharp.dll gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glib-sharp/2.10.0.0__35e10195dab3c99f/glib-sharp.dll glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.pango-sharp.dll policy.2.8.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.glib-sharp.dll policy.2.8.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-dotnet/2.10.0.0__35e10195dab3c99f/gtk-dotnet.dll gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.4.gtk-dotnet.dll policy.2.4.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/pango-sharp/2.10.0.0__35e10195dab3c99f/pango-sharp.dll pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/atk-sharp/2.10.0.0__35e10195dab3c99f/atk-sharp.dll atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gdk-sharp.dll policy.2.6.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gdk-sharp.dll policy.2.8.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gtk-sharp.dll policy.2.4.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.glib-sharp.dll policy.2.4.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glade-sharp/2.10.0.0__35e10195dab3c99f/glade-sharp.dll glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.atk-sharp.dll policy.2.6.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.8.gtk-dotnet.dll policy.2.8.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.atk-sharp.dll policy.2.8.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.pango-sharp.dll policy.2.4.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.glib-sharp.dll policy.2.6.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.atk-sharp.dll policy.2.4.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gtk-sharp.dll policy.2.8.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.glade-sharp.dll policy.2.6.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gdk-sharp.dll policy.2.4.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.glade-sharp.dll policy.2.8.glade-sharp.dll )

==> gtk-sharp-2.12.1-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.gdk-sharp.dll policy.2.10.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.4.gtk-dotnet.dll policy.2.4.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.10.gtk-dotnet.dll policy.2.10.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.8.gtk-dotnet.dll policy.2.8.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gtk-sharp.dll policy.2.4.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gdk-sharp.dll policy.2.6.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-sharp/2.12.0.0__35e10195dab3c99f/gtk-sharp.dll gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.atk-sharp.dll policy.2.8.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.pango-sharp.dll policy.2.6.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.glade-sharp.dll policy.2.6.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.gtk-sharp.dll policy.2.10.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glib-sharp/2.12.0.0__35e10195dab3c99f/glib-sharp.dll glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.glib-sharp.dll policy.2.6.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gtk-sharp.dll policy.2.6.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gdk-sharp.dll policy.2.8.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-dotnet/2.12.0.0__35e10195dab3c99f/gtk-dotnet.dll gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gtk-dotnet/0.0.0.0__35e10195dab3c99f/policy.2.6.gtk-dotnet.dll policy.2.6.gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.atk-sharp.dll policy.2.4.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.pango-sharp.dll policy.2.4.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.glade-sharp.dll policy.2.4.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.pango-sharp.dll policy.2.10.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.glade-sharp.dll policy.2.10.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gtk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gtk-sharp.dll policy.2.8.gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/atk-sharp/2.12.0.0__35e10195dab3c99f/atk-sharp.dll atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.atk-sharp.dll policy.2.10.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gdk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gdk-sharp.dll policy.2.4.gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.glib-sharp.dll policy.2.4.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.10.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.10.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.10.glib-sharp.dll policy.2.10.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.glib-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.glib-sharp.dll policy.2.8.glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.pango-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.pango-sharp.dll policy.2.8.pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.glade-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.glade-sharp.dll policy.2.8.glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.atk-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.atk-sharp.dll policy.2.6.atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/pango-sharp/2.12.0.0__35e10195dab3c99f/pango-sharp.dll pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glade-sharp/2.12.0.0__35e10195dab3c99f/glade-sharp.dll glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gdk-sharp/2.12.0.0__35e10195dab3c99f/gdk-sharp.dll gdk-sharp.dll )
